package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Apr 1, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FakeExecParams struct {
WantCmd []string `json:"want_cmd"`
Output string `json:"output"`
ExitCode int `json:"exit_code"`
}
nolint:musttag
Source Files
¶
Click to show internal directories.
Click to hide internal directories.